import router from './router'
import store from './store'
import NProgress from 'nprogress'
import 'nprogress/nprogress.css'
import { getToken } from '@/utils/auth'

NProgress.configure({ showSpinner: false })

const whiteList = [
  '/index',
  '/login',
  '/auth-redirect',
  '/bind',
  '/register',
  '/news/index',
  '/news/newDetail',
  '/notice/index',
  '/supply/index',
  '/interaction/index',
  '/register/index',
  '/register/registerType',
  '/register/userRegister',
  '/register/companyRegister',
  '/biddingHall',
  '/authenticRight',
  '/authenticRight/login',
  '/project',
  '/policy',
  '/policyDetail',
  '/attestationDetail',
  '/noticeDetail',
  '/homestead/login',
  '/applicationForm',
  '/applicationList',
  '/certificateList',
  '/certificateSee',
  '/informationList',
  '/circulationList',
  '/circulationAdd',
  '/onlineHomeLogin',
  '/onlineHomeIndex',
  '/onlineHome/publicity',
  '/onlineHome/workbench',
  '/onlineHome/home',
  '/onlineHome/my',
  '/onlineHome/threeAffairs',
  '/onlineHome/homePoll',
  '/onlineHome/incomeDetail',
  '/onlineHome/inAndOutDetail',
  '/onlineHome/expenditureDetail',
  '/onlineHome/mailList',
  '/onlineHome/password',
  '/onlineHome/livePay',
  '/onlineHome/advice',
  '/onlineHome/done',
  '/onlineHome/personalPicture',
]

router.beforeEach((to, from, next) => {
  NProgress.start()
  if (getToken()) {
    /* has token*/
    if (to.path === '/login') {
      next({ path: '/' })
      NProgress.done()
    } else {
      if (store.getters.roles.length === 0) {
        next()
        // 判断当前用户是否已拉取完user_info信息
        store.dispatch('GetInfo').then(res => {
          // 拉取user_info
          const roles = res.roles
          // store.dispatch('GenerateRoutes', { roles }).then(accessRoutes => {
          //   // 根据roles权限生成可访问的路由表
          //   router.addRoutes(accessRoutes) // 动态添加可访问路由表
          //   next({ ...to, replace: true }) // hack方法 确保addRoutes已完成
          // })
          next()
        }).catch(err => {
          store.dispatch('LogOut').then(() => {
            // Message.error(err)
            if ('/authenticRight/index'.indexOf(to.path) !== -1) {
              next({ path: '/authenticRight/login' })
            } else if ('/homestead/index'.indexOf(to.path) !== -1) {
              next({ path: '/homestead/login' })
            } else {
              next({ path: '/' })
            }
          })
        })
      } else {
        next()
      }
    }
  } else {
    // 没有token
    if (whiteList.indexOf(to.path) !== -1) {
      // 在免登录白名单，直接进入
      next()
    } else {
      if ('/authenticRight/index'.indexOf(to.path) !== -1) {
        next(`/authenticRight/login?redirect=${to.fullPath}`)
      } else if ('/homestead/index'.indexOf(to.path) !== -1) {
        next(`/homestead/login?redirect=${to.fullPath}`)
      } else {
        next(`/login?redirect=${to.fullPath}`)
      }

      //  // 否则全部重定向到登录页
      //next('/index');
      NProgress.done()
    }
  }
})

router.afterEach(() => {
  NProgress.done()
})
